| MAplotW | R Documentation |
This type of plot for display of relative changes versus (mean) absolute abundance is very common in high-throughput biology, see MA-plot.
MAplotW(
Mvalue,
Avalue = NULL,
useComp = 1,
filtFin = NULL,
tit = NULL,
ProjNa = NULL,
FCthrs = NULL,
subTxt = NULL,
grayIncrem = TRUE,
col = NULL,
pch = 16,
compNa = NULL,
batchFig = FALSE,
cexMa = 1.8,
cexLa = 1.1,
limM = NULL,
limp = NULL,
annotColumn = c("SpecType", "GeneName", "EntryName", "Accession", "Species", "Contam"),
annColor = NULL,
expFCarrow = FALSE,
cexPt = NULL,
cexSub = NULL,
cexTxLab = 0.7,
namesNBest = NULL,
NbestCol = 1,
colBySpecType = FALSE,
sortLeg = "descend",
NaSpecTypeAsContam = TRUE,
useMar = c(6.2, 4, 4, 2),
returnData = FALSE,
callFrom = NULL,
silent = FALSE,
debug = FALSE
)
Mvalue |
(numeric, list or MArrayLM-object) main data to plot; if numeric, the content will be used as M-values (and A-values must be provided separateley);
if list or MArrayLM-object, it must conatin list-elements named |
Avalue |
(numeric, list or data.frame) if |
useComp |
(integer) choice of one of multiple comparisons present in |
filtFin |
(matrix or logical) The data may get filtered before plotting: If |
tit |
(character) custom title |
ProjNa |
(character) add project-name to (automatic) title |
FCthrs |
(numeric) Fold-Change threshold (display as line) give as Fold-change and NOT log2(FC) |
subTxt |
(character) custom sub-title |
grayIncrem |
(logical) if |
col |
(character) custom color(s) for points of plot (see also |
pch |
(integer) type of symbol(s) to plot (default=16) (see also |
compNa |
(character) names of groups compared |
batchFig |
(logical) if |
cexMa |
(numeric) font-size of title, as expansion factor (see also |
cexLa |
(numeric) size of axis-labels, as expansion factor (see also |
limM |
(numeric, length=2) range of axis M-values |
limp |
(numeric, length=2) range of axis FDR / p-values |
annotColumn |
(character) column names of annotation to be extracted (only if |
annColor |
(character or integer) colors for specific groups of annotation (only if |
expFCarrow |
(logical, character or numeric) optional adding arrow for expected fold-change; if |
cexPt |
(numeric) size of points, as expansion factor (see also |
cexSub |
(numeric) size of subtitle, as expansion factor (see also |
cexTxLab |
(numeric) size of text-labels for points, as expansion factor (see also |
namesNBest |
(integer or character) for display of labels to points in figure: if 'pass','passThr' or 'signif' all points passing thresholds; if numeric (length=1) this number of best points will get labels
if the initial object |
NbestCol |
(character or integer) colors for text-labels of best points, also used for arrow |
colBySpecType |
(logical) incase arument |
sortLeg |
(character) sorting of 'SpecType' annotation either ascending ('ascend') or descending ('descend'), no sorting if |
NaSpecTypeAsContam |
(logical) consider lines/proteins with |
useMar |
(numeric, length=4) custom margings (see also |
returnData |
(logical) optional returning data.frame with (ID, Mvalue, pValue, FDRvalue, passFilt) |
callFrom |
(character) allow easier tracking of messages produced |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
Using an MMA-plot one compares two independent series of measures (ie gene transcript or protein abundance values) of 2 samples/data-sets or the means of 2 groups of replicates.
Basically, the plot will dispaly a log-transformed ratio (log-fold-change) of both mesures ('Minus'=M) against the mean value of both mesures ('Average'=A).
As with omics-data it is habit to with with log2-data, the ratio/fold-change can be obatined by subtraction this axis is also called 'Minus'=M)
Furthermore, output from statistical testing by moderTest2grp or moderTestXgrp can be directly read to produce MA-plots, which are mriomarily used for diagnostic purposes.
Please note, that plotting a very high number of points in transparency (eg >10000) may take several seconds.
This function plots an MA-plot (to the current graphical device); if returnData=TRUE, a data.frame with ($ID, $Mvalue, $Avalue, $passFilt) gets returned
(for PCA) plotPCAw
library(wrMisc)
set.seed(2005); mat <- matrix(round(runif(600),2), ncol=6)
rownames(mat) <- paste(rep(letters[1:25],each=4), letters[2:26])
MAplotW(mat[,2] -mat[,1], A=rowMeans(mat[,1:2]))
## assume 2 groups with 3 samples each
matMeans <- rowGrpMeans(mat, gr=gl(2,3,labels=LETTERS[3:4]))
MAplotW(M=matMeans[,2] -matMeans[,1], A=rowMeans(mat))
## assume 2 groups with 3 samples each and run moderated t-test (from package 'limma')
tRes <- moderTest2grp(mat, gl(2,3))
MAplotW(tRes$Mval, tRes$Amean)
MAplotW(M=tRes$Mval, A=rowMeans(tRes$means), FCth=1.3)
MAplotW(tRes)
MAplotW(tRes, limM=c(-2,2), FCth=1.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.